@@ -190,12 +190,14 @@ try:
         all,
         min,
         max,
+        median,
         moment,
         trace,
         argmin,
         argmax,
         nansum,
         nanmean,
+        nanmedian,
         nanstd,
         nanvar,
         nanmin,
