@@ -42,6 +42,7 @@ from .numpy_compat import _unravel_index_keyword
 
 @derived_from(np)
 def array(x, dtype=None, ndmin=None):
+    x = asarray(x)
     while ndmin is not None and x.ndim < ndmin:
         x = x[None, :]
     if dtype is not None and x.dtype != dtype:
@@ -348,8 +349,7 @@ def apply_along_axis(func1d, axis, arr, *args, dtype=None, shape=None, **kwargs)
     :func:`dask.array.map_blocks`
 
     Parameters
-    __________
-
+    ----------
     func1d : callable
         Function to apply to 1-D slices of the array along the given axis
     axis : int
