@@ -94,7 +94,7 @@ def ttest_ind(a, b, axis=0, equal_var=True):
 def ttest_1samp(a, popmean, axis=0, nan_policy="propagate"):
     if nan_policy != "propagate":
         raise NotImplementedError(
-            "`nan_policy` other than 'propagate' " "have not been implemented."
+            "`nan_policy` other than 'propagate' have not been implemented."
         )
     n = a.shape[axis]
     df = n - 1
@@ -113,7 +113,7 @@ def ttest_1samp(a, popmean, axis=0, nan_policy="propagate"):
 def ttest_rel(a, b, axis=0, nan_policy="propagate"):
     if nan_policy != "propagate":
         raise NotImplementedError(
-            "`nan_policy` other than 'propagate' " "have not been implemented."
+            "`nan_policy` other than 'propagate' have not been implemented."
         )
 
     n = a.shape[axis]
@@ -187,7 +187,7 @@ def power_divergence(f_obs, f_exp=None, ddof=0, axis=0, lambda_=None):
 def skew(a, axis=0, bias=True, nan_policy="propagate"):
     if nan_policy != "propagate":
         raise NotImplementedError(
-            "`nan_policy` other than 'propagate' " "have not been implemented."
+            "`nan_policy` other than 'propagate' have not been implemented."
         )
 
     n = a.shape[axis]  # noqa; for bias
@@ -214,7 +214,7 @@ def skew(a, axis=0, bias=True, nan_policy="propagate"):
 def skewtest(a, axis=0, nan_policy="propagate"):
     if nan_policy != "propagate":
         raise NotImplementedError(
-            "`nan_policy` other than 'propagate' " "have not been implemented."
+            "`nan_policy` other than 'propagate' have not been implemented."
         )
 
     b2 = skew(a, axis)
@@ -245,7 +245,7 @@ def skewtest(a, axis=0, nan_policy="propagate"):
 def kurtosis(a, axis=0, fisher=True, bias=True, nan_policy="propagate"):
     if nan_policy != "propagate":
         raise NotImplementedError(
-            "`nan_policy` other than 'propagate' " "have not been implemented."
+            "`nan_policy` other than 'propagate' have not been implemented."
         )
     n = a.shape[axis]  # noqa; for bias
     m2 = moment(a, 2, axis)
@@ -272,7 +272,7 @@ def kurtosis(a, axis=0, fisher=True, bias=True, nan_policy="propagate"):
 def kurtosistest(a, axis=0, nan_policy="propagate"):
     if nan_policy != "propagate":
         raise NotImplementedError(
-            "`nan_policy` other than 'propagate' " "have not been implemented."
+            "`nan_policy` other than 'propagate' have not been implemented."
         )
 
     n = float(a.shape[axis])
@@ -309,7 +309,7 @@ def kurtosistest(a, axis=0, nan_policy="propagate"):
 def normaltest(a, axis=0, nan_policy="propagate"):
     if nan_policy != "propagate":
         raise NotImplementedError(
-            "`nan_policy` other than 'propagate' " "have not been implemented."
+            "`nan_policy` other than 'propagate' have not been implemented."
         )
 
     s, _ = skewtest(a, axis)
@@ -357,7 +357,7 @@ def f_oneway(*args):
 def moment(a, moment=1, axis=0, nan_policy="propagate"):
     if nan_policy != "propagate":
         raise NotImplementedError(
-            "`nan_policy` other than 'propagate' " "have not been implemented."
+            "`nan_policy` other than 'propagate' have not been implemented."
         )
     return da.moment(a, moment, axis=axis)
 
@@ -367,9 +367,8 @@ def moment(a, moment=1, axis=0, nan_policy="propagate"):
 # -------
 # Don't really want to do all of scipy.special (or do we?)
 
-
-_xlogy = wrap_elemwise(special.xlogy)
-_fdtrc = wrap_elemwise(special.fdtrc)
+_xlogy = wrap_elemwise(special.xlogy, source=special)
+_fdtrc = wrap_elemwise(special.fdtrc, source=special)
 
 
 def _equal_var_ttest_denom(v1, n1, v2, n2):
