@@ -2,12 +2,17 @@ import warnings
 
 import numpy as np
 import pandas as pd
-from pandas.util import hash_pandas_object
 from pandas.api.types import is_categorical_dtype, union_categoricals
-from pandas._libs.algos import groupsort_indexer
 from toolz import partition
 
-from .utils import PANDAS_VERSION, is_series_like, is_dataframe_like, PANDAS_GT_0250
+from .utils import (
+    PANDAS_VERSION,
+    is_series_like,
+    is_dataframe_like,
+    PANDAS_GT_0250,
+    hash_object_dispatch,
+    group_split_dispatch,
+)
 from ..utils import Dispatch
 
 if PANDAS_VERSION >= "0.23":
@@ -226,6 +231,23 @@ def describe_nonnumeric_aggregate(stats, name):
     return pd.Series(values, index=index, name=name)
 
 
+def _cum_aggregate_apply(aggregate, x, y):
+    """ Apply aggregation function within a cumulative aggregation
+
+    Parameters
+    ----------
+    aggregate: function (a, a) -> a
+        The aggregation function, like add, which is used to and subsequent
+        results
+    x:
+    y:
+    """
+    if y is None:
+        return x
+    else:
+        return aggregate(x, y)
+
+
 def cummin_aggregate(x, y):
     if is_series_like(x) or is_dataframe_like(x):
         return x.where((x < y) | x.isnull(), y, axis=x.ndim - 1)
@@ -360,6 +382,9 @@ def concat_pandas(dfs, axis=0, join="outer", uniform=False, filter_warning=True)
     # Support concatenating indices along axis 0
     if isinstance(dfs[0], pd.Index):
         if isinstance(dfs[0], pd.CategoricalIndex):
+            for i in range(1, len(dfs)):
+                if not isinstance(dfs[i], pd.CategoricalIndex):
+                    dfs[i] = dfs[i].astype("category")
             return pd.CategoricalIndex(union_categoricals(dfs), name=dfs[0].name)
         elif isinstance(dfs[0], pd.MultiIndex):
             first, rest = dfs[0], dfs[1:]
@@ -480,32 +505,12 @@ def concat_pandas(dfs, axis=0, join="outer", uniform=False, filter_warning=True)
     return out
 
 
+# cuDF may try to import old dispatch functions
+hash_df = hash_object_dispatch
+group_split = group_split_dispatch
+
+
 def assign_index(df, ind):
     df = df.copy()
     df.index = ind
     return df
-
-
-# ---------------------------------
-# Shuffling/merging/sorting
-# ---------------------------------
-
-
-hash_df = Dispatch("hash_df")
-
-
-@hash_df.register((pd.DataFrame, pd.Series, pd.Index))
-def hash_df_pandas(dfs):
-    return hash_pandas_object(dfs, index=False)
-
-
-group_split = Dispatch("group_split")
-
-
-@group_split.register((pd.DataFrame, pd.Series, pd.Index))
-def group_split_pandas(df, c, k):
-    indexer, locations = groupsort_indexer(c, k)
-    df2 = df.take(indexer)
-    locations = locations.cumsum()
-    parts = [df2.iloc[a:b] for a, b in zip(locations[:-1], locations[1:])]
-    return dict(zip(range(k), parts))
