@@ -4,9 +4,17 @@ import warnings
 import pytest
 import numpy as np
 import pandas as pd
+from pandas.api.types import is_datetime64_ns_dtype
 
 import dask.dataframe as dd
-from dask.dataframe.utils import assert_eq, assert_dask_graph, make_meta, HAS_INT_NA
+from dask.dataframe._compat import PANDAS_GT_100
+from dask.dataframe.utils import (
+    assert_eq,
+    assert_dask_graph,
+    make_meta,
+    HAS_INT_NA,
+    PANDAS_GT_0250,
+)
 
 
 @pytest.mark.slow
@@ -588,6 +596,7 @@ def test_frame_series_arithmetic_methods():
             # pandas-26793
             warnings.simplefilter("ignore", RuntimeWarning)
             assert_eq(l.div(r, fill_value=0), el.div(er, fill_value=0))
+            assert_eq(l.divide(r, fill_value=0), el.divide(er, fill_value=0))
             assert_eq(l.truediv(r, fill_value=0), el.truediv(er, fill_value=0))
             assert_eq(l.floordiv(r, fill_value=1), el.floordiv(er, fill_value=1))
             assert_eq(l.pow(r, fill_value=0), el.pow(er, fill_value=0))
@@ -602,7 +611,9 @@ def test_frame_series_arithmetic_methods():
 
             assert_eq(l.rdiv(r, fill_value=0), el.rdiv(er, fill_value=0))
             assert_eq(l.rtruediv(r, fill_value=0), el.rtruediv(er, fill_value=0))
-            assert_eq(l.rfloordiv(r, fill_value=1), el.rfloordiv(er, fill_value=1))
+            if not PANDAS_GT_0250:
+                # https://github.com/pandas-dev/pandas/issues/27464
+                assert_eq(l.rfloordiv(r, fill_value=1), el.rfloordiv(er, fill_value=1))
             assert_eq(l.rpow(r, fill_value=0), el.rpow(er, fill_value=0))
             assert_eq(l.rmod(r, fill_value=0), el.rmod(er, fill_value=0))
 
@@ -616,6 +627,7 @@ def test_frame_series_arithmetic_methods():
         assert_eq(l.sub(r, axis=0), el.sub(er, axis=0))
         assert_eq(l.mul(r, axis=0), el.mul(er, axis=0))
         assert_eq(l.div(r, axis=0), el.div(er, axis=0))
+        assert_eq(l.divide(r, axis=0), el.divide(er, axis=0))
         assert_eq(l.truediv(r, axis=0), el.truediv(er, axis=0))
         assert_eq(l.floordiv(r, axis=0), el.floordiv(er, axis=0))
         assert_eq(l.mod(r, axis=0), el.mod(er, axis=0))
@@ -626,7 +638,9 @@ def test_frame_series_arithmetic_methods():
         assert_eq(l.rmul(r, axis=0), el.rmul(er, axis=0))
         assert_eq(l.rdiv(r, axis=0), el.rdiv(er, axis=0))
         assert_eq(l.rtruediv(r, axis=0), el.rtruediv(er, axis=0))
-        assert_eq(l.rfloordiv(r, axis=0), el.rfloordiv(er, axis=0))
+        if not PANDAS_GT_0250:
+            # https://github.com/pandas-dev/pandas/issues/27464
+            assert_eq(l.rfloordiv(r, axis=0), el.rfloordiv(er, axis=0))
         assert_eq(l.rmod(r, axis=0), el.rmod(er, axis=0))
         assert_eq(l.rpow(r, axis=0), el.rpow(er, axis=0))
 
@@ -641,6 +655,7 @@ def test_frame_series_arithmetic_methods():
             assert_eq(l.sub(r, axis=axis), el.sub(er, axis=axis))
             assert_eq(l.mul(r, axis=axis), el.mul(er, axis=axis))
             assert_eq(l.div(r, axis=axis), el.div(er, axis=axis))
+            assert_eq(l.divide(r, axis=axis), el.divide(er, axis=axis))
             assert_eq(l.truediv(r, axis=axis), el.truediv(er, axis=axis))
             with warnings.catch_warnings():
                 # https://github.com/pandas-dev/pandas/issues/26793
@@ -650,7 +665,9 @@ def test_frame_series_arithmetic_methods():
                 assert_eq(l.pow(r, axis=axis), el.pow(er, axis=axis))
                 assert_eq(l.rdiv(r, axis=axis), el.rdiv(er, axis=axis))
                 assert_eq(l.rtruediv(r, axis=axis), el.rtruediv(er, axis=axis))
-                assert_eq(l.rfloordiv(r, axis=axis), el.rfloordiv(er, axis=axis))
+                if not PANDAS_GT_0250:
+                    # https://github.com/pandas-dev/pandas/issues/27464
+                    assert_eq(l.rfloordiv(r, axis=axis), el.rfloordiv(er, axis=axis))
                 assert_eq(l.rpow(r, axis=axis), el.rpow(er, axis=axis))
                 assert_eq(l.rmod(r, axis=axis), el.rmod(er, axis=axis))
 
@@ -783,13 +800,6 @@ def test_reductions_timedelta(split_every):
     ds = pd.Series(pd.to_timedelta([2, 3, 4, np.nan, 5]))
     dds = dd.from_pandas(ds, 2)
 
-    with pytest.warns(None):
-        # runtime warnings; https://github.com/dask/dask/issues/2381
-        assert_eq(dds.var(split_every=split_every), ds.var())
-        assert_eq(dds.var(split_every=split_every, skipna=False), ds.var(skipna=False))
-
-    assert_eq(dds.var(ddof=0, split_every=split_every), ds.var(ddof=0))
-
     assert_eq(dds.sum(split_every=split_every), ds.sum())
     assert_eq(dds.min(split_every=split_every), ds.min())
     assert_eq(dds.max(split_every=split_every), ds.max())
@@ -802,12 +812,12 @@ def test_reductions_timedelta(split_every):
         (
             pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}, index=[0, 1, 3]),
             0,
-            pd.Series([]),
+            pd.Series([], dtype="float64"),
         ),
         (
             pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}, index=[0, 1, 3]),
             1,
-            pd.Series([]),
+            pd.Series([], dtype="float64"),
         ),
         (pd.Series([1, 2.5, 6]), None, None),
     ],
@@ -974,7 +984,9 @@ def test_reductions_non_numeric_dtypes():
     check_raises(dds, pds, "std")
     check_raises(dds, pds, "var")
     check_raises(dds, pds, "sem")
-    check_raises(dds, pds, "mean")
+    if not PANDAS_GT_0250:
+        # pandas 0.25 added DatetimeIndex.mean. We need to follow.
+        check_raises(dds, pds, "mean")
     assert_eq(dds.nunique(), pds.nunique())
 
     for pds in [
@@ -992,7 +1004,9 @@ def test_reductions_non_numeric_dtypes():
         check_raises(dds, pds, "std")
         check_raises(dds, pds, "var")
         check_raises(dds, pds, "sem")
-        check_raises(dds, pds, "mean")
+        if not (PANDAS_GT_0250 and is_datetime64_ns_dtype(pds.dtype)):
+            # pandas 0.25 added DatetimeIndex.mean. We need to follow
+            check_raises(dds, pds, "mean")
         assert_eq(dds.nunique(), pds.nunique())
 
     pds = pd.Series(pd.timedelta_range("1 days", freq="D", periods=5))
@@ -1004,7 +1018,6 @@ def test_reductions_non_numeric_dtypes():
 
     # ToDo: pandas supports timedelta std, dask returns float64
     # assert_eq(dds.std(), pds.std())
-    assert_eq(dds.var(), pds.var())
 
     # ToDo: pandas supports timedelta std, otherwise dask raises:
     # TypeError: unsupported operand type(s) for *: 'float' and 'Timedelta'
@@ -1112,7 +1125,10 @@ def test_reductions_frame_dtypes():
     )
 
     if HAS_INT_NA:
-        df["intna"] = pd.array([1, 2, 3, 4, None, 6, 7, 8], dtype=pd.Int64Dtype())
+        if not PANDAS_GT_0250:
+            # Pandas master is returning NA for IntegerNA.sum() when mixed with other dtypes.
+            # https://github.com/pandas-dev/pandas/issues/27185
+            df["intna"] = pd.array([1, 2, 3, 4, None, 6, 7, 8], dtype=pd.Int64Dtype())
 
     ddf = dd.from_pandas(df, 3)
 
@@ -1120,23 +1136,45 @@ def test_reductions_frame_dtypes():
     df_no_timedelta = df.drop("timedelta", axis=1, inplace=False)
     ddf_no_timedelta = dd.from_pandas(df_no_timedelta, 3)
 
-    assert_eq(df.sum(), ddf.sum())
+    if not PANDAS_GT_100:
+        # https://github.com/pandas-dev/pandas/issues/30886
+        assert_eq(df.sum(), ddf.sum())
+        assert_eq(df_no_timedelta.mean(), ddf_no_timedelta.mean())
+    else:
+        assert_eq(df.drop(columns="dt").sum(), ddf.drop(columns="dt").sum())
+        assert_eq(
+            df_no_timedelta.drop(columns="dt").mean(),
+            ddf_no_timedelta.drop(columns="dt").mean(),
+        )
+
     assert_eq(df.prod(), ddf.prod())
     assert_eq(df.min(), ddf.min())
     assert_eq(df.max(), ddf.max())
     assert_eq(df.count(), ddf.count())
     assert_eq(df_no_timedelta.std(), ddf_no_timedelta.std())
-    assert_eq(df.var(), ddf.var())
-    assert_eq(df.var(skipna=False), ddf.var(skipna=False))
+    assert_eq(df_no_timedelta.var(), ddf_no_timedelta.var())
+    if PANDAS_GT_0250:
+        # https://github.com/pandas-dev/pandas/issues/18880
+        assert_eq(
+            df.drop("timedelta", axis=1).var(skipna=False),
+            ddf.drop("timedelta", axis=1).var(skipna=False),
+        )
+    else:
+        assert_eq(df.var(skipna=False), ddf.var(skipna=False))
 
     assert_eq(df.sem(), ddf.sem())
     assert_eq(df_no_timedelta.std(ddof=0), ddf_no_timedelta.std(ddof=0))
-    assert_eq(df.var(ddof=0), ddf.var(ddof=0))
-    assert_eq(df.var(ddof=0, skipna=False), ddf.var(ddof=0, skipna=False))
+    if PANDAS_GT_0250:
+        # https://github.com/pandas-dev/pandas/issues/18880
+        df2 = df.drop("timedelta", axis=1)
+        ddf2 = ddf.drop("timedelta", axis=1)
+        assert_eq(df2.var(ddof=0), ddf2.var(ddof=0))
+        assert_eq(df2.var(ddof=0, skipna=False), ddf2.var(ddof=0, skipna=False))
+    else:
+        assert_eq(df.var(ddof=0), ddf.var(ddof=0))
+        assert_eq(df.var(ddof=0, skipna=False), ddf.var(ddof=0, skipna=False))
     assert_eq(df.sem(ddof=0), ddf.sem(ddof=0))
 
-    assert_eq(df_no_timedelta.mean(), ddf_no_timedelta.mean())
-
     assert_eq(df._get_numeric_data(), ddf._get_numeric_data())
 
     numerics = ddf[["int", "float"]]
@@ -1297,3 +1335,14 @@ def test_divmod():
     expected = divmod(df1, df2)
     assert_eq(result[0], expected[0])
     assert_eq(result[1], expected[1])
+
+
+def test_moment():
+    scipy = pytest.importorskip("scipy")
+    from dask.array import stats
+    from dask.array.utils import assert_eq
+
+    df = pd.Series(list(range(10)))
+    ddf = dd.from_pandas(df, npartitions=2)
+
+    assert_eq(stats.moment(ddf, 2, 0), scipy.stats.moment(df, 2, 0))
