@@ -13,19 +13,50 @@ from dask.multiprocessing import get, _dumps, get_context, remote_exception
 from dask.utils_test import inc
 
 
+try:
+    import cloudpickle  # noqa: F401
+
+    has_cloudpickle = True
+except ImportError:
+    has_cloudpickle = False
+
+requires_cloudpickle = pytest.mark.skipif(
+    not has_cloudpickle, reason="requires cloudpickle"
+)
+not_cloudpickle = pytest.mark.skipif(has_cloudpickle, reason="cloudpickle is installed")
+
+
+def unrelated_function_global(a):
+    return np.array([a])
+
+
+def my_small_function_global(a, b):
+    return a + b
+
+
 def test_pickle_globals():
     """ Unrelated globals should not be included in serialized bytes """
+    b = _dumps(my_small_function_global)
+    assert b"my_small_function_global" in b
+    assert b"unrelated_function_global" not in b
+    assert b"numpy" not in b
 
-    def unrelated_function(a):
+
+@requires_cloudpickle
+def test_pickle_locals():
+    """Unrelated locals should not be included in serialized bytes
+    """
+
+    def unrelated_function_local(a):
         return np.array([a])
 
-    def my_small_function(a, b):
+    def my_small_function_local(a, b):
         return a + b
 
-    b = _dumps(my_small_function)
-    assert b"my_small_function" in b
-    assert b"unrelated_function" not in b
-    assert b"numpy" not in b
+    b = _dumps(my_small_function_local)
+    assert b"my_small_function_global" not in b
+    assert b"my_small_function_local" in b
+    assert b"unrelated_function_local" not in b
 
 
 def bad():
@@ -35,11 +66,9 @@ def bad():
 def test_errors_propagate():
     dsk = {"x": (bad,)}
 
-    try:
+    with pytest.raises(ValueError) as e:
         get(dsk, "x")
-    except Exception as e:
-        assert isinstance(e, ValueError)
-        assert "12345" in str(e)
+    assert "12345" in str(e.value)
 
 
 def test_remote_exception():
@@ -54,19 +83,37 @@ def test_remote_exception():
     assert "traceback-body" in str(a)
 
 
-def make_bad_result():
+@requires_cloudpickle
+def test_lambda_with_cloudpickle():
+    dsk = {"x": 2, "y": (lambda x: x + 1, "x")}
+    assert get(dsk, "y") == 3
+
+
+@not_cloudpickle
+def test_lambda_without_cloudpickle():
+    dsk = {"x": 2, "y": (lambda x: x + 1, "x")}
+    with pytest.raises(ModuleNotFoundError) as e:
+        get(dsk, "y")
+    assert "cloudpickle" in str(e.value)
+
+
+def lambda_result():
     return lambda x: x + 1
 
 
-def test_unpicklable_results_generate_errors():
+@requires_cloudpickle
+def test_lambda_results_with_cloudpickle():
+    dsk = {"x": (lambda_result,)}
+    f = get(dsk, "x")
+    assert f(2) == 3
 
-    dsk = {"x": (make_bad_result,)}
 
-    try:
+@not_cloudpickle
+def test_lambda_results_without_cloudpickle():
+    dsk = {"x": (lambda_result,)}
+    with pytest.raises(ModuleNotFoundError) as e:
         get(dsk, "x")
-    except Exception as e:
-        # can't use type because pickle / cPickle distinction
-        assert type(e).__name__ in ("PicklingError", "AttributeError")
+    assert "cloudpickle" in str(e.value)
 
 
 class NotUnpickleable(object):
@@ -80,22 +127,15 @@ class NotUnpickleable(object):
 def test_unpicklable_args_generate_errors():
     a = NotUnpickleable()
 
-    def foo(a):
-        return 1
+    dsk = {"x": (bool, a)}
 
-    dsk = {"x": (foo, a)}
-
-    try:
+    with pytest.raises(ValueError):
         get(dsk, "x")
-    except Exception as e:
-        assert isinstance(e, ValueError)
 
-    dsk = {"x": (foo, "a"), "a": a}
+    dsk = {"x": (bool, "a"), "a": a}
 
-    try:
+    with pytest.raises(ValueError):
         get(dsk, "x")
-    except Exception as e:
-        assert isinstance(e, ValueError)
 
 
 def test_reuse_pool():
@@ -125,18 +165,29 @@ def test_optimize_graph_false():
     assert len(keys) == 2
 
 
+@requires_cloudpickle
 @pytest.mark.parametrize("random", [np.random, random])
 def test_random_seeds(random):
+    @delayed(pure=False)
     def f():
         return tuple(random.randint(0, 10000) for i in range(5))
 
     N = 10
     with dask.config.set(scheduler="processes"):
-        (results,) = compute([delayed(f, pure=False)() for i in range(N)])
+        (results,) = compute([f() for _ in range(N)])
 
     assert len(set(results)) == N
 
 
+def check_for_pytest():
+    """We check for spawn by ensuring subprocess doesn't have modules only
+    parent process should have:
+    """
+    import sys
+
+    return "FAKE_MODULE_FOR_TEST" in sys.modules
+
+
 @pytest.mark.skipif(
     sys.platform == "win32", reason="Windows doesn't support different contexts"
 )
@@ -147,13 +198,6 @@ def test_custom_context_used_python3_posix():
     context is changed this test will need to be modified to be different than
     that.
     """
-    # We check for spawn by ensuring subprocess doesn't have modules only
-    # parent process should have:
-    def check_for_pytest():
-        import sys
-
-        return "FAKE_MODULE_FOR_TEST" in sys.modules
-
     sys.modules["FAKE_MODULE_FOR_TEST"] = 1
     try:
         with dask.config.set({"multiprocessing.context": "spawn"}):
@@ -171,7 +215,8 @@ def test_get_context_using_python3_posix():
 
     If default context is changed this test will need to change too.
     """
-    assert get_context() is multiprocessing.get_context(None)
+    default_context = None if sys.platform != "darwin" else "fork"
+    assert get_context() is multiprocessing.get_context(default_context)
     with dask.config.set({"multiprocessing.context": "forkserver"}):
         assert get_context() is multiprocessing.get_context("forkserver")
     with dask.config.set({"multiprocessing.context": "spawn"}):
